@@ -30,10 +30,6 @@
 #include <libgames-support/games-controls.h>
 #include <libgames-support/games-pause-action.h>
 
-#ifdef GGZ_CLIENT
-#include "ggz-network.h"
-#endif
-
 #include "preferences.h"
 #include "main.h"
 
@@ -50,18 +46,6 @@ extern GnibblesProperties *properties;
 GtkWidget *start_level_label, *start_level_spin_button;
 GtkWidget *num_human, *num_ai;
 
-
-static void
-network_set_preferences (void)
-{
-#ifdef GGZ_CLIENT
-  if (ggz_network_mode) {
-    network_req_settings (properties->gamespeed,
-                          properties->fakes, properties->startlevel);
-  }
-#endif
-}
-
 static void
 destroy_cb (GtkWidget * widget, gpointer data)
 {
@@ -69,7 +53,6 @@ destroy_cb (GtkWidget * widget, gpointer data)
     gtk_action_activate (pause_action);
     unpause = 0;
   }
-  network_set_preferences ();
   pref_dialog = NULL;
 }
 
@@ -318,7 +301,7 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
     gtk_check_button_new_with_mnemonic (_("_Play levels in random order"));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
-  if (running || ggz_network_mode)
+  if (running)
     gtk_widget_set_sensitive (button, FALSE);
   if (properties->random)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
@@ -380,7 +363,7 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
   gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 
   gtk_table_attach (GTK_TABLE (table2), label2, 0, 1, 1, 2, GTK_FILL, 0, 0,  0);
-  if (running || ggz_network_mode)
+  if (running)
     gtk_widget_set_sensitive (label2, FALSE);
 
   adjustment = gtk_adjustment_new ((gfloat) properties->human, 0.0,
@@ -391,7 +374,7 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label2), num_human);
 
   gtk_table_attach_defaults (GTK_TABLE (table2), num_human, 1, 2, 1, 2);
-  if (running || ggz_network_mode)
+  if (running)
     gtk_widget_set_sensitive (num_human, FALSE);
   g_signal_connect (GTK_ADJUSTMENT (adjustment), "value_changed",
                     G_CALLBACK (num_worms_cb), num_human);
@@ -400,7 +383,7 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
   gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 
   gtk_table_attach (GTK_TABLE (table2), label2, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
-  if (running || ggz_network_mode)
+  if (running)
     gtk_widget_set_sensitive (label2, FALSE);
 
   adjustment = gtk_adjustment_new ((gfloat) properties->ai, 0.0,
@@ -411,7 +394,7 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label2), num_ai);
 
   gtk_table_attach_defaults (GTK_TABLE (table2), num_ai, 1, 2, 2, 3);
-  if (running || ggz_network_mode)
+  if (running)
     gtk_widget_set_sensitive (num_ai, FALSE);
   g_signal_connect (GTK_ADJUSTMENT (adjustment), "value_changed",
                     G_CALLBACK (num_worms_cb), num_ai);
